==========================
Unihandecode documentation
==========================

Introduction
============

ASCII transliterations of Unicode text that recognize CJKV complex charactors


COPYRIGHTS
==========

Unicode Character Database
==========================

Date: 2010-09-23 09:29:58 UDT [JHJ]
Unicode version: 6.0.0

Copyright (c) 1991-2010 Unicode, Inc.
For terms of use, see http://www.unicode.org/terms_of_use.html
For documentation, see http://www.unicode.org/reports/tr44/


Unidecode's character transliteration tables
============================================

Copyright 2001, Sean M. Burke <sburke@cpan.org>, all rights reserved.

Python code
===========

Copyright 2010,2011, Hiroshi Miura <miurahr@linux.com>
Copyright 2009, Tomaz Solc <tomaz@zemanta.com>


=================
Table of contents
=================

.. toctree::
   :maxdepth: 2



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

